==> xkaapi-2.1.tar.gz: xkaapi-2.1/src/memory/kaapi_memory_bind.c <==
/*
 ** xkaapi
 ** 
 ** Copyright 2009,2010,2011,2012 INRIA.
 **
 ** Contributors :
 **
 ** thierry.gautier@inrialpes.fr
 ** fabien.lementec@imag.fr
 ** Joao.Lima@imagf.r / joao.lima@inf.ufrgs.br
 ** 
 ** This software is a computer program whose purpose is to execute
 ** multithreaded computation with data flow synchronization between
 ** threads.
 ** 
 ** This software is governed by the CeCILL-C license under French law
 ** and abiding by the rules of distribution of free software.  You can
 ** use, modify and/ or redistribute the software under the terms of
 ** the CeCILL-C license as circulated by CEA, CNRS and INRIA at the
 ** following URL "http://www.cecill.info".
 ** 
 ** As a counterpart to the access to the source code and rights to
 ** copy, modify and redistribute granted by the license, users are
 ** provided only with a limited warranty and the software's author,
 ** the holder of the economic rights, and the successive licensors
 ** have only limited liability.
 ** 
 ** In this respect, the user's attention is drawn to the risks
 ** associated with loading, using, modifying and/or developing or
 ** reproducing the software by the user in light of its specific
 ** status of free software, that may mean that it is complicated to
 ** manipulate, and that also therefore means that it is reserved for
 ** developers and experienced professionals having in-depth computer
 ** knowledge. Users are therefore encouraged to load and test the
 ** software's suitability as regards their requirements in conditions
 ** enabling the security of their systems and/or data to be ensured
 ** and, more generally, to use and operate it in the same conditions
 ** as regards security.
 ** 
 ** The fact that you are presently reading this means that you have
 ** had knowledge of the CeCILL-C license and that you accept its
 ** terms.
 ** 
 */

#include "kaapi_impl.h"

kaapi_metadata_info_t* kaapi_memory_find_metadata( void* ptr )
{
  kaapi_memory_map_t* const kmap = kaapi_memory_map_get_current(kaapi_get_self_kid());
  kaapi_metadata_info_t* kmdi;
  
  kmdi = kaapi_memory_map_find_or_insert(kmap, ptr);
  
#if 0
  kaapi_memory_address_space_fprintf(stdout, kaapi_memory_map_get_current_asid());
#endif
  
  return kmdi;
}

kaapi_version_t** kaapi_metadata_info_bind_data(
                                                kaapi_metadata_info_t* kmdi,
                                                kaapi_address_space_id_t kasid,
                                                void* ptr, const kaapi_memory_view_t* view
                                                )
{
  kaapi_metadata_info_set_data(kmdi, kasid, ptr, view);
  kaapi_metadata_info_clear_dirty(kmdi, kasid);
  return kaapi_metadata_info_get_version_by_lid_(kmdi, kaapi_memory_address_space_getlid(kasid));
}

kaapi_metadata_info_t* kaapi_memory_bind(
                                         kaapi_address_space_id_t kasid,
                                         int flag,
                                         void* ptr,
                                         size_t size
                                         )
{
  kaapi_metadata_info_t* const kmdi = kaapi_memory_find_metadata(ptr);
  kaapi_memory_view_t view = kaapi_memory_view_make1d(size, 1);
  kaapi_metadata_info_bind_data(kmdi, kasid, ptr, &view);
  
  return kmdi;
}

kaapi_metadata_info_t* kaapi_memory_bind_with_metadata(
                                                       kaapi_address_space_id_t kasid,
                                                       kaapi_metadata_info_t* const kmdi,
                                                       int flag,
                                                       void* ptr,
                                                       size_t size
                                                       )
{
  kaapi_memory_map_t* const kmap = kaapi_memory_map_get_current(kaapi_get_self_kid());
  kaapi_memory_map_find_and_insert(kmap, ptr, kmdi);
  kaapi_memory_view_t view = kaapi_memory_view_make1d(size, 1);
  kaapi_metadata_info_bind_data(kmdi, kasid, ptr, &view);
  
  return kmdi;
}

kaapi_metadata_info_t* kaapi_memory_bind_view(
                                              kaapi_address_space_id_t kasid,
                                              int flag,
                                              void* ptr,
                                              const kaapi_memory_view_t* view
                                              )
{
  kaapi_metadata_info_t* const kmdi = kaapi_memory_find_metadata(ptr);
  kaapi_metadata_info_bind_data(kmdi, kasid, ptr, view);
  return kmdi;
}

kaapi_metadata_info_t* kaapi_memory_bind_view_with_metadata(
                                                            kaapi_address_space_id_t kasid,
                                                            kaapi_metadata_info_t* const kmdi,
                                                            int flag,
                                                            void* ptr,
                                                            const kaapi_memory_view_t* view
                                                            )
{
  kaapi_memory_map_t* const kmap = kaapi_memory_map_get_current(kaapi_get_self_kid());
  kaapi_memory_map_find_and_insert(kmap, ptr, kmdi);
  kaapi_metadata_info_bind_data(kmdi, kasid, ptr, view);
  return kmdi;
}

void* kaapi_memory_unbind( kaapi_metadata_info_t* kmdi )
{
  kaapi_assert(0); // TODO
  void* retval = 0;
  //  kaapi_metadata_info_unbind_alldata(kmdi); TODO
  return retval;
}

==> xkaapi-2.2.tar.gz: xkaapi-2.2/src/memory/kaapi_memory_bind.c <==
/*
 ** xkaapi
 ** 
 ** Copyright 2009,2010,2011,2012 INRIA.
 **
 ** Contributors :
 **
 ** thierry.gautier@inrialpes.fr
 ** fabien.lementec@imag.fr
 ** Joao.Lima@imagf.r / joao.lima@inf.ufrgs.br
 ** 
 ** This software is a computer program whose purpose is to execute
 ** multithreaded computation with data flow synchronization between
 ** threads.
 ** 
 ** This software is governed by the CeCILL-C license under French law
 ** and abiding by the rules of distribution of free software.  You can
 ** use, modify and/ or redistribute the software under the terms of
 ** the CeCILL-C license as circulated by CEA, CNRS and INRIA at the
 ** following URL "http://www.cecill.info".
 ** 
 ** As a counterpart to the access to the source code and rights to
 ** copy, modify and redistribute granted by the license, users are
 ** provided only with a limited warranty and the software's author,
 ** the holder of the economic rights, and the successive licensors
 ** have only limited liability.
 ** 
 ** In this respect, the user's attention is drawn to the risks
 ** associated with loading, using, modifying and/or developing or
 ** reproducing the software by the user in light of its specific
 ** status of free software, that may mean that it is complicated to
 ** manipulate, and that also therefore means that it is reserved for
 ** developers and experienced professionals having in-depth computer
 ** knowledge. Users are therefore encouraged to load and test the
 ** software's suitability as regards their requirements in conditions
 ** enabling the security of their systems and/or data to be ensured
 ** and, more generally, to use and operate it in the same conditions
 ** as regards security.
 ** 
 ** The fact that you are presently reading this means that you have
 ** had knowledge of the CeCILL-C license and that you accept its
 ** terms.
 ** 
 */

#include "kaapi_impl.h"

kaapi_metadata_info_t* kaapi_memory_find_metadata( void* const ptr, const size_t size )
{
  kaapi_memory_map_t* const kmap = kaapi_memory_map_get_current(kaapi_get_self_kid());
  kaapi_metadata_info_t* kmdi;
  
  kmdi = kaapi_memory_map_find_or_insert(kmap, kaapi_memory_map_key_(ptr,size));
  
#if 0
  kaapi_memory_address_space_fprintf(stdout, kaapi_memory_map_get_current_asid());
#endif
  
  return kmdi;
}

kaapi_metadata_info_t* kaapi_memory_find_metadata_by_asid( const kaapi_address_space_id_t kasid, void* const ptr, const size_t size )
{
  kaapi_memory_map_t* const kmap = kaapi_memory_map_get_by_asid(kasid);
  kaapi_metadata_info_t* kmdi;
  
  kmdi = kaapi_memory_map_find_or_insert(kmap, kaapi_memory_map_key_(ptr, size));
  
  return kmdi;
}

kaapi_version_t** kaapi_metadata_info_bind_data(
                                                kaapi_metadata_info_t* kmdi,
                                                kaapi_address_space_id_t kasid,
                                                void* ptr, const kaapi_memory_view_t* view
                                                )
{
  kaapi_metadata_info_set_data(kmdi, kasid, ptr, view);
  kaapi_metadata_info_clear_dirty(kmdi, kasid);
  return kaapi_metadata_info_get_version_by_lid_(kmdi, kaapi_memory_address_space_getlid(kasid));
}

kaapi_metadata_info_t* kaapi_memory_bind(
                                         kaapi_address_space_id_t kasid,
                                         int flag,
                                         void* ptr,
                                         size_t size
                                         )
{
  kaapi_metadata_info_t* const kmdi = kaapi_memory_find_metadata(ptr, size);
  kaapi_memory_view_t view = kaapi_memory_view_make1d(size, 1);
  kaapi_metadata_info_bind_data(kmdi, kasid, ptr, &view);
  
  return kmdi;
}

kaapi_metadata_info_t* kaapi_memory_bind_with_metadata(
                                                       kaapi_address_space_id_t kasid,
                                                       kaapi_metadata_info_t* const kmdi,
                                                       int flag,
                                                       void* ptr,
                                                       size_t size
                                                       )
{
  kaapi_memory_map_t* const kmap = kaapi_memory_map_get_by_asid(kasid);
  kaapi_memory_map_find_and_insert(kmap, kaapi_memory_map_key_(ptr, size), kmdi);
  kaapi_memory_view_t view = kaapi_memory_view_make1d(size, 1);
  kaapi_metadata_info_bind_data(kmdi, kasid, ptr, &view);
  
  return kmdi;
}

kaapi_metadata_info_t* kaapi_memory_bind_view(
                                              kaapi_address_space_id_t kasid,
                                              int flag,
                                              void* ptr,
                                              const kaapi_memory_view_t* view
                                              )
{
  kaapi_metadata_info_t* const kmdi = kaapi_memory_find_metadata_by_asid(kasid, ptr, kaapi_memory_view_size(view));
  kaapi_metadata_info_bind_data(kmdi, kasid, ptr, view);
#if 0
  fprintf(stdout, "%d:%s: kmdi=%p lid=%d ptr=%p size=%d\n", kaapi_get_self_kid(), __FUNCTION__,
          kmdi, kaapi_memory_address_space_getlid(kasid), ptr, kaapi_memory_view_size(view));
  fflush(stdout);
#endif
  return kmdi;
}

kaapi_metadata_info_t* kaapi_memory_bind_view_with_metadata(
                                                            kaapi_address_space_id_t kasid,
                                                            kaapi_metadata_info_t* const kmdi,
                                                            int flag,
                                                            void* ptr,
                                                            const kaapi_memory_view_t* view
                                                            )
{
  kaapi_memory_map_t* const kmap = kaapi_memory_map_get_by_asid(kasid);
  kaapi_memory_map_find_and_insert(kmap, kaapi_memory_map_key_(ptr, kaapi_memory_view_size(view)), kmdi);
  kaapi_metadata_info_bind_data(kmdi, kasid, ptr, view);
#if 0
  fprintf(stdout, "%d:%s: kmdi=%p lid=%d ptr=%p size=%d\n", kaapi_get_self_kid(), __FUNCTION__,
          kmdi, kaapi_memory_address_space_getlid(kasid), ptr, kaapi_memory_view_size(view));
  fflush(stdout);
#endif  
  return kmdi;
}

void* kaapi_memory_unbind( kaapi_metadata_info_t* kmdi )
{
  kaapi_assert(0); // TODO
  void* retval = 0;
  //  kaapi_metadata_info_unbind_alldata(kmdi); TODO
  return retval;
}
